@@ -1,6 +1,9 @@
 /*
  * Worldvisions Weaver Software:
- *   Copyright (C) 1997, 1998 Worldvisions Computer Technology, Inc.
+ *   Copyright (C) 1997, 1998, 1999 Worldvisions Computer Technology, Inc.
+ *
+ * WvFileWatcher test.  Opens a file, /tmp/test.txt, and displays new
+ * additions to this file as they occur.
  */
 #include "wvlog.h"
 #include "wvwatcher.h"
@@ -9,7 +12,7 @@ int main()
 {
     WvLog log("watchtest", WvLog::Info);
     const WvString fname("/tmp/test.txt");
-    WvFileWatcher f(fname.str, O_RDONLY | O_CREAT);
+    WvFileWatcher f(fname, O_RDONLY | O_CREAT | O_TRUNC);
     char buf[1024];
     size_t len;
     
