@@ -1,6 +1,6 @@
 /*
  * Worldvisions Weaver Software:
- *   Copyright (C) 1997, 1998 Worldvisions Computer Technology, Inc.
+ *   Copyright (C) 1997, 1998, 1999 Worldvisions Computer Technology, Inc.
  * 
  * Implementation of a WvPipe stream.  These allow you to create a new
  * process, attaching its stdin/stdout to a WvStream.
@@ -32,7 +32,7 @@ class WvPipe : public WvStream
     pid_t pid;
     int estatus;
 protected:
-    void setup(const char *program, char **argv,
+    void setup(const char *program, const char **argv,
 	       bool writable, bool readable, bool catch_stderr,
 	       int stdin_fd, int stdout_fd, int stderr_fd);
 public:
@@ -43,7 +43,7 @@ public:
     //    - redirect it through the WvPipe (eg. if writable==true)
     //    - redirect it to any open file descriptor (std*_fd are only
     //       used if the corresponding bool is false, however)
-    WvPipe(const char *program, char **argv,
+    WvPipe(const char *program, const char **argv,
 	   bool writable, bool readable, bool catch_stderr,
 	   int stdin_fd = 0, int stdout_fd = 1, int stderr_fd = 2);
     
@@ -56,16 +56,16 @@ public:
     // bool is false; otherwise, we redirect to the pipe.
     //
     // It is okay for the same WvStream to occur more than once.  Also,
-    // you must naturally make sure that the stream does not disappear
+    // you must naturally make sure that the stream doesn't disappear
     // before WvPipe does!
-    WvPipe(const char *program, char **argv,
+    WvPipe(const char *program, const char **argv,
 	   bool writable, bool readable, bool catch_stderr,
 	   WvStream *stdin_str, WvStream *stdout_str = NULL,
 	   WvStream *stderr_str = NULL);
     
     // This constructor is the same again, except that it uses the features
     // of the WvSplitStream class to get all its fds from one place.
-    WvPipe(const char *program, char **argv,
+    WvPipe(const char *program, const char **argv,
 	   bool writable, bool readable, bool catch_stderr,
 	   WvSplitStream *stdio_str);
 
