@@ -1,6 +1,6 @@
 /*
  * Worldvisions Weaver Software:
- *   Copyright (C) 1997, 1998 Worldvisions Computer Technology, Inc.
+ *   Copyright (C) 1997, 1998, 1999 Worldvisions Computer Technology, Inc.
  * 
  * WvStreamClone simply forwards all requests to the "cloned" stream.
  * 
@@ -8,6 +8,7 @@
  */
 #include "wvstreamclone.h"
 #include <errno.h>
+#include <time.h>
 
 
 WvStreamClone::~WvStreamClone()
@@ -42,21 +43,15 @@ size_t WvStreamClone::uread(void *buf, size_t size)
 
 size_t WvStreamClone::uwrite(const void *buf, size_t size)
 {
+    // we use s()->uwrite() here, not write(), since we want the _clone_
+    // to own the output buffer, not the main stream.
     if (s())
-	return s()->write(buf, size);
+	return s()->uwrite(buf, size);
     else
 	return 0;
 }
 
 
-bool WvStreamClone::test_set(fd_set &r, fd_set &w, fd_set &x)
-{
-    if (s())
-	return s()->test_set(r, w, x);
-    return false;
-}
-
-
 bool WvStreamClone::isok() const
 {
     if (errnum)
@@ -87,16 +82,37 @@ const char *WvStreamClone::errstr() const
 }
 
 
-bool WvStreamClone::select_setup(fd_set &r, fd_set &w, fd_set &x, int &max_fd,
-				 bool readable, bool writable, bool isexcept)
+bool WvStreamClone::select_setup(SelectInfo &si)
 {
-    if (readable && !select_ignores_buffer && inbuf.used() 
+    bool oldwr, result;
+    
+    if (si.readable && !select_ignores_buffer && inbuf.used() 
 	   && inbuf.used() >= queue_min)
 	return true;   // sure_thing if anything in WvStream buffer
+    
+    if (s() && s()->isok())
+    {
+	oldwr = si.writable;
+	if (outbuf.used() || autoclose_time)
+	    si.writable = true;
+	
+	result = s()->select_setup(si);
+	
+	si.writable = oldwr;
+	return result;
+	
+    }
+    return false;
+}
 
-    if (s())
-	return s()->select_setup(r, w, x, max_fd,
-				 readable, writable, isexcept);
+
+bool WvStreamClone::test_set(SelectInfo &si)
+{
+    if (s() && (outbuf.used() || autoclose_time))
+	flush(0);
+
+    if (s() && s()->isok())
+	return s()->test_set(si);
     return false;
 }
 
