@@ -1,6 +1,6 @@
 /*
  * Worldvisions Weaver Software:
- *   Copyright (C) 1997, 1998 Worldvisions Computer Technology, Inc.
+ *   Copyright (C) 1997, 1998, 1999 Worldvisions Computer Technology, Inc.
  * 
  * WvStreamList holds a list of WvStream objects -- and its select() and
  * callback() functions know how to handle multiple simultaneous streams.
@@ -17,12 +17,14 @@ class WvStreamList : public WvStream, public WvStreamListBase
 {
 public:
     WvStreamList();
+    virtual ~WvStreamList();
     virtual bool isok() const;
-    virtual bool select_setup(fd_set &r, fd_set &w, fd_set &x, int &max_fd,
-			      bool readable, bool writable, bool isexception);
-    virtual bool test_set(fd_set &r, fd_set &w, fd_set &x);
+    virtual bool select_setup(SelectInfo &si);
+    virtual bool test_set(SelectInfo &si);
     virtual void execute();
     
+    bool auto_prune; // remove !isok() streams from the list automatically?
+    
 protected:
     WvStreamListBase sure_thing;
 };
