@@ -1,6 +1,6 @@
 /*
  * Worldvisions Weaver Software:
- *   Copyright (C) 1997, 1998 Worldvisions Computer Technology, Inc.
+ *   Copyright (C) 1997, 1998, 1999 Worldvisions Computer Technology, Inc.
  * 
  * The WvFileWatcher class provides support for files which sometimes
  * have data appended at the end.  It only polls as often as your select()
@@ -22,7 +22,7 @@ WvFileWatcher::WvFileWatcher(const char *_filename, int _mode)
     once_ok = WvFile::isok();
     openmode = _mode;
     fpos = 0;
-    if (stat(filename.str, &last_st) && WvFile::isok())
+    if (stat(filename, &last_st) && WvFile::isok())
     {
 	errnum = errno;
 	close();
@@ -43,7 +43,7 @@ bool WvFileWatcher::make_ok(bool retry)
     // time, or we cannot stat the file, close it and start over.
     struct stat st;
     if (fd >= 0 
-	&& (stat(filename.str, &st)
+	&& (stat(filename, &st)
 	    || st.st_ino != last_st.st_ino || st.st_size < last_st.st_size))
     {
 	close();
@@ -53,13 +53,13 @@ bool WvFileWatcher::make_ok(bool retry)
     while (!WvFile::isok())
     {
 	fpos = 0;
-	if (!open(filename.str, openmode) && retry)
+	if (!open(filename, openmode) && retry)
 	    sleep(1);
 	if (!retry && !WvFile::isok())
 	    return false; // no such luck
     }
 
-    stat(filename.str, &last_st);
+    stat(filename, &last_st);
     return true;
 }
 
@@ -96,31 +96,30 @@ size_t WvFileWatcher::uwrite(const void *buf, size_t size)
 // or you want to write to it.  Otherwise the file is "not ready."
 // Because this happens in select_setup, the file will only be checked as
 // often as your select() delay.  So infinite delays are a bad idea!
-bool WvFileWatcher::select_setup(fd_set &r, fd_set &w, fd_set &x, int &max_fd,
-			      bool readable, bool writable, bool isexception)
+bool WvFileWatcher::select_setup(SelectInfo &si)
 {
     struct stat st;
     
     if (!once_ok) return false;
     
-    if (writable)
+    if (si.writable)
 	return true; // always writable
     
-    if (!readable)
+    if (!si.readable)
 	return false; // what are you asking?
     
     // readable if the current location pointer is < size
-    if (fd >= 0 && readable && !fstat(fd, &st) && fpos < st.st_size)
+    if (fd >= 0 && si.readable && !fstat(fd, &st) && fpos < st.st_size)
 	return true;
 	    
     // get the file open, at least
     if (make_ok(false))
     {
 	// writable as long as file is open
-	if (writable)
+	if (si.writable)
 	    return true;
 	
-	if (readable && fpos < last_st.st_size)
+	if (si.readable && fpos < last_st.st_size)
 	    return true;
     }
     
