@@ -1,6 +1,6 @@
 /*
  * Worldvisions Weaver Software:
- *   Copyright (C) 1997, 1998 Worldvisions Computer Technology, Inc.
+ *   Copyright (C) 1997, 1998, 1999 Worldvisions Computer Technology, Inc.
  * 
  * The WvFileWatcher class provides support for files which sometimes
  * have data appended at the end.  It only polls as often as your select()
@@ -34,8 +34,7 @@ public:
     virtual bool isok() const;
     virtual size_t uread(void *buf, size_t size);
     virtual size_t uwrite(const void *buf, size_t size);
-    virtual bool select_setup(fd_set &r, fd_set &w, fd_set &x, int &max_fd,
-			      bool readable, bool writable, bool isexception);
+    virtual bool select_setup(SelectInfo &si);
 };
 
 #endif // __WVWATCHER_H
