@@ -1,12 +1,9 @@
 /*
  * Worldvisions Weaver Software:
- *   Copyright (C) 1997, 1998 Worldvisions Computer Technology, Inc.
+ *   Copyright (C) 1997, 1998, 1999 Worldvisions Computer Technology, Inc.
  *
- * Various little utilities used primarily in the WvConfigFile class.
+ * Various little string functions...
  *
- * Created:	Sept 12 1997	D. Coombs
- * Modified:	Nov  11 1997	D. Coombs
- * 
  */
 
 #ifndef __STRUTILS_H
@@ -19,7 +16,10 @@ extern char *trim_string( char *string );
 extern void replace_char( void *string, char c1, char c2, int length );
 extern char *strlwr( char * string );
 extern bool is_word( char * string );
-WvString hexdump_buffer(unsigned char *buf, size_t len);
+extern WvString hexdump_buffer( unsigned char *buf, size_t len );
 extern bool isnewline( char c );
+extern void hexify( char *obuf, unsigned char *ibuf, size_t len );
+extern void unhexify( unsigned char *obuf, char *ibuf );
+
 
 #endif // __STRUTILS_H
