@@ -1,6 +1,6 @@
 /*
  * Worldvisions Weaver Software:
- *   Copyright (C) 1997, 1998 Worldvisions Computer Technology, Inc.
+ *   Copyright (C) 1997, 1998, 1999 Worldvisions Computer Technology, Inc.
  *
  * The brains behind the WvDialer class.  This handles prompt-detection,
  * menu-guessing, and related tasks.
@@ -44,7 +44,7 @@ void WvDialBrain::reset()
     prompt_response = "";
 }
 
-char * WvDialBrain::guess_menu( char * buf )
+const char * WvDialBrain::guess_menu( char * buf )
 /******************************************/
 // Searches buf for signs of intelligence, and tries to guess how to
 // start PPP on the remote side.  Good for terminal servers with menus,
@@ -83,9 +83,11 @@ char * WvDialBrain::guess_menu( char * buf )
     	return( NULL );
 }
 
-char * WvDialBrain::check_prompt( const char * buffer )
+const char * WvDialBrain::check_prompt( const char * buffer )
 /*****************************************************/
 {
+    WvString tprompt;
+    
     // If we've been here too many times, or too long ago, just give up and
     // start pppd.
     if( prompt_tries >= 5 || time( NULL ) - dialer->last_rx >= 5 ) {
@@ -95,7 +97,7 @@ char * WvDialBrain::check_prompt( const char * buffer )
 
     } else if( is_login_prompt( buffer ) ) {
     	// We have a login prompt, so send a suitable response.
-    	char * send_this = dialer->options.login.str;
+    	const char * send_this = dialer->options.login;
     	dialer->log( "Looks like a login prompt.\n"
     		     "Sending: %s\n", send_this );
     	dialer->reset_offset();
@@ -109,7 +111,7 @@ char * WvDialBrain::check_prompt( const char * buffer )
     	prompt_tries++;
     	sent_login = 1;	// yes, we've sent a password:
     			// assume we've sent username too.
-    	return( dialer->options.password.str );
+    	return( dialer->options.password );
 
     } else if( is_welcome_msg( buffer ) ) {
     	dialer->log( "Looks like a welcome message.\n" );
@@ -121,7 +123,7 @@ char * WvDialBrain::check_prompt( const char * buffer )
     	    return( NULL );	// figure it out next time
     	}
 
-    	if( !prompt_response.str[0] )
+    	if( !prompt_response[0] )
     	    prompt_response = dialer->options.default_reply;	// wild guess
 
     	dialer->log( "Hmm... a prompt.  Sending \"%s\".\n",
@@ -129,7 +131,12 @@ char * WvDialBrain::check_prompt( const char * buffer )
     	dialer->reset_offset();
     	prompt_tries++;
 
-    	return( prompt_response.str );
+	// only use our prompt guess the first time.
+	// if it fails, go back to the default reply.
+	tprompt = prompt_response;
+	prompt_response = "";
+	
+    	return( tprompt );
 
     } else {
     	// not a prompt at all!
@@ -157,14 +164,14 @@ bool WvDialBrain::is_prompt( const char * c,
 // looking for a SPECIFIC prompt that contains that string.
 {
     const char *	cptr;
-    static const char *	prompt_punct	= ")>}]:.|-?$";
+    static const char *	prompt_punct	= ")>}]:.|-?$%=";
     
     // if no promptstring was given, the search is simple:  it is a 
     // prompt if the last line ends in punctuation and no newline.
     if( !promptstring ) {
 	for( cptr = c + strlen( c ) - 1; cptr >= c; cptr-- ) {
 	    if( isnewline( *cptr ) ) {
-		if ( !prompt_response.str[0] )
+		if ( !prompt_response[0] )
 		    return( false ); // last line was empty: not a prompt
 		else
 		    return( true ); // we have a guess, so use it anyway
@@ -244,16 +251,17 @@ bool WvDialBrain::is_login_prompt( const char * buf )
     	    is_prompt( buf, "user.id", true ) ||
     	    is_prompt( buf, "signon" ) ||
     	    is_prompt( buf, "sign.on", true ) ||
-    	    ( dialer->options.login_prompt.str[0] &&
-    	      is_prompt( buf, dialer->options.login_prompt.str ) ) );
+    	    is_prompt( buf, "usuario", false ) ||
+    	    ( dialer->options.login_prompt[0] &&
+    	      is_prompt( buf, dialer->options.login_prompt ) ) );
 }
 
 bool WvDialBrain::is_password_prompt( const char * buf )
 /******************************************************/
 {
     return( is_prompt( buf, "password" ) ||
-      ( dialer->options.pass_prompt.str[0] &&
-        is_prompt( buf, dialer->options.pass_prompt.str ) ) );
+      ( dialer->options.pass_prompt[0] &&
+        is_prompt( buf, dialer->options.pass_prompt ) ) );
 }
 
 bool WvDialBrain::is_welcome_msg( const char * buf )
@@ -530,10 +538,10 @@ void WvDialBrain::set_prompt_response( char * str )
 {
     WvString	n;
 
-    if( strcmp( str, prompt_response.str ) ) {
+    if( strcmp( str, prompt_response ) ) {
 	n.setsize( strlen( str ) + 1 );
-	strcpy( n.str, str );
-	n.str[ strlen( str ) ] = '\0';
+	strcpy( n.edit(), str );
+	n.edit()[ strlen( str ) ] = '\0';
 
     	dialer->log( "Found a good menu option: \"%s\".\n", n );
     	prompt_response = n;
