@@ -1,6 +1,6 @@
 /*
  * Worldvisions Weaver Software:
- *   Copyright (C) 1997, 1998 Worldvisions Computer Technology, Inc.
+ *   Copyright (C) 1997, 1998, 1999 Worldvisions Computer Technology, Inc.
  *
  * Implementation of the WvDialer smart-dialer class.  
  *
@@ -51,10 +51,11 @@ static char *	prompt_strings[] = {
 //       WvDialer Public Functions
 //**************************************************
 
-WvDialer::WvDialer( WvConf& cfg, WvStringList& sect_list )
+WvDialer::WvDialer( WvConf &_cfg, WvStringList *_sect_list, bool _chat_mode = false )
 /********************************************************/
 : WvStreamClone( (WvStream **)&modem ),
-    log( "WvDial", WvLog::Debug ), err( log.split( WvLog::Error ) ),
+    cfg(_cfg), log( "WvDial", WvLog::Debug ),
+    err( log.split( WvLog::Error ) ),
     modemrx( "Modem", WvLog::Debug )
 {
     modem 		 = NULL;
@@ -68,28 +69,27 @@ WvDialer::WvDialer( WvConf& cfg, WvStringList& sect_list )
     auto_reconnect_delay = 0;
     auto_reconnect_at    = 0;
     connected_at         = 0;
+    weird_pppd_problem   = false;
+    
+    sect_list = _sect_list;
+    chat_mode = _chat_mode;
     
     log( "WvDial: Internet dialer version " WVDIAL_VER_STRING "\n" );
 
     // Ensure all sections in sect_list actually exist, warning if not.
-    WvStringList::Iter	iter( sect_list );
+    WvStringList::Iter	iter( *sect_list );
     for( iter.rewind(); iter.next(); ) {
-    	if( cfg.get_section( iter.data()->str ) == NULL ) {
+    	if( cfg[iter] == NULL ) {
     	    err( WvLog::Warning,
 		 "Warning: section [%s] does not exist in wvdial.conf.\n",
-    	    	 iter.data()->str );
+    	    	 iter );
     	}
     }
 
     // Activate the brain and read configuration.
     brain = new WvDialBrain( this );
-    load_options( cfg, sect_list );
 
-    if( !options.modem.str[0] ) {
-	err( "Configuration does not specify a valid modem device.\n" );
-    	stat = ModemError;
-	return; // if we get this error, we already have a problem.
-    }
+    // init_modem() reads the config options.  It MUST run here!
     
     if( !init_modem() )
     {
@@ -108,31 +108,34 @@ WvDialer::~WvDialer()
 	delete modem;
     if( brain )
     	delete brain;
+    if( sect_list )
+	delete sect_list;
 }
 
 bool WvDialer::dial()
 /*******************/
 // Returns false on error, or true to go asynchronous while dialing.
 {
-    if( stat == Online ) {
+    if( stat == Online )
     	return( true );
-    } else if( stat != Idle ) {
+	
+    if( stat != Idle ) {
 	// (error message has already been printed elsewhere)
     	// err( "Modem is not ready to dial.\n" );
     	return( false );
     }
 
-    if( !options.phnum.str[0] ) {
+    if( !options.phnum[0] ) {
 	err( "Configuration does not specify a valid phone number.\n" );
     	stat = OtherError;
     }
 
-    if( !options.login.str[0] ) {
+    if( !options.login[0] ) {
 	err( "Configuration does not specify a valid login name.\n" );
     	stat = OtherError;
     }
 
-    if( !options.password.str[0] ) {
+    if( !options.password[0] ) {
 	err( "Configuration does not specify a valid password.\n" );
     	stat = OtherError;
     }
@@ -140,15 +143,17 @@ bool WvDialer::dial()
     if( stat != Idle )
 	return( false );
 
-    stat = Dial;
-    connect_attempts = 1;
-    dial_stat = 0;
-    brain->reset();
-    
     // we need to re-init the modem if we were online before.
     if( been_online && !init_modem() )
 	stat = ModemError;
-
+    else
+    {
+	stat = Dial;
+	connect_attempts = 1;
+	dial_stat = 0;
+	brain->reset();
+    }
+    
     return( true );
 }
 
@@ -161,22 +166,20 @@ void WvDialer::hangup()
     }
 
     if( stat != Idle ) {
-	if( modem && !modem->isok() ) {
-    	    stat = ModemError;
-	    return;
-	}
-
 	time_t 	now;
 	time( &now );
 	log( "Disconnecting at %s", ctime( &now ) );
 	if( modem )
+	{
 	    modem->hangup();
+	    delete modem;
+	    modem = NULL;
+	}
 	stat = Idle;
     }
 }
 
-bool WvDialer::select_setup( fd_set &r, fd_set &w, fd_set &x, int &max_fd,
-			     bool readable, bool writable, bool isexception )
+bool WvDialer::select_setup(SelectInfo &si)
 /**************************************************************************/
 {
     if( isok() && stat != Online && stat != Idle
@@ -188,16 +191,18 @@ bool WvDialer::select_setup( fd_set &r, fd_set &w, fd_set &x, int &max_fd,
 	// we need to execute() even if no modem data is incoming.
 	return( true );
     } else {
-	return WvStreamClone::select_setup( r, w, x, max_fd,
-					    readable, writable, isexception );
+	return WvStreamClone::select_setup( si );
     }
 }
 
 bool WvDialer::isok() const
 /*************************/
 {
-    return( (!modem || modem->isok())
-    	&& stat != ModemError && stat != OtherError );
+    bool b = (!modem || modem->isok())
+	&& stat != ModemError && stat != OtherError;
+    if (!b)
+	fprintf(stderr, "Returning not ok!!\n");
+    return b;
 }
 
 char * WvDialer::connect_status() const
@@ -278,6 +283,7 @@ void WvDialer::execute()
     	async_waitprompt();
     	break;
     case Online:
+	assert( !chat_mode );
     	// If already online, we only need to make sure pppd is still there.
 	if( ppp_pipe && ppp_pipe->child_exited() ) {
 	    if( ppp_pipe->child_killed() ) {
@@ -294,6 +300,13 @@ void WvDialer::execute()
 	    hangup();
 	    delete( modem );
 	    modem = NULL;
+	    
+	    if( time( NULL ) - connected_at < 45 ) {
+		weird_pppd_problem = true;
+	    } else {
+		weird_pppd_problem = false;
+	    }
+		
 
 	    // check to see if we're supposed to redial automatically soon.
 	    if( options.auto_reconnect && isok() ) {
@@ -342,7 +355,7 @@ void WvDialer::execute()
 //       WvDialer Private Functions
 //**************************************************
 
-void WvDialer::load_options( WvConf& cfg, WvStringList& sect_list )
+void WvDialer::load_options()
 /*****************************************************************/
 {
     OptInfo opts[] = {
@@ -359,6 +372,7 @@ void WvDialer::load_options( WvConf& cfg, WvStringList& sect_list )
     	{ "Init9",           &options.init9,        NULL, "",               0 },
     	{ "Phone",           &options.phnum,        NULL, "",               0 },
     	{ "Dial Prefix",     &options.dial_prefix,  NULL, "",               0 },
+    	{ "Area Code",       &options.areacode,     NULL, "",               0 },
     	{ "Dial Command",    &options.dial_cmd,     NULL, "ATDT",           0 },
     	{ "Username",        &options.login,        NULL, "",               0 },
     	{ "Login Prompt",    &options.login_prompt, NULL, "",               0 },
@@ -374,7 +388,7 @@ void WvDialer::load_options( WvConf& cfg, WvStringList& sect_list )
     	{ "Baud",            NULL, &options.baud,          "", DEFAULT_BAUD },
     	{ "Carrier Check",   NULL, &options.carrier_check, "", true         },
     	{ "Stupid Mode",     NULL, &options.stupid_mode,   "", false        },
-    	{ "New PPPD",	     NULL, &options.new_pppd, 	   "", false	    },
+    	{ "New PPPD",	     NULL, &options.new_pppd, 	   "", true         },
     	{ "Auto Reconnect",  NULL, &options.auto_reconnect,"", true	    },
     	{ NULL,		     NULL, NULL,                   "", 0            }
     };
@@ -385,12 +399,12 @@ void WvDialer::load_options( WvConf& cfg, WvStringList& sect_list )
     	if( opts[i].str_member == NULL ) {
     	    // it's an int/bool option.
     	    *( opts[i].int_member ) =
-    	    		cfg.fuzzy_get( sect_list, opts[i].name,
-    	    		    cfg.get( d, opts[i].name, opts[i].int_default ) );
+		cfg.fuzzy_getint( *sect_list, opts[i].name,
+		       cfg.getint( d, opts[i].name, opts[i].int_default ) );
     	} else {
     	    // it's a string option.
     	    *( opts[i].str_member ) = 
-    	    		cfg.fuzzy_get( sect_list, opts[i].name, 
+    	    		cfg.fuzzy_get( *sect_list, opts[i].name, 
     	    		    cfg.get( d, opts[i].name, opts[i].str_default ) );
     	}
     }
@@ -400,20 +414,32 @@ bool WvDialer::init_modem()
 /*************************/
 {
     int	received;
+    
+    load_options();
+
+    if( modem ) delete modem;
+    
+    if( !options.modem[0] ) {
+	err( "Configuration does not specify a valid modem device.\n" );
+    	stat = ModemError;
+	return( false ); // if we get this error, we already have a problem.
+    }
 
     // Open the modem...
-    if( !modem ) {
-	modem = new WvModem( options.modem.str, options.baud );
-	if( !modem->isok() ) {
-	    err( "Cannot open %s: %s\n", options.modem, modem->errstr() );
-    	    return( false );
-	}
+    if( chat_mode )
+	modem = new WvModemBase( STDIN_FILENO );
+    else
+	modem = new WvModem( options.modem, options.baud );
+    if( !modem->isok() ) {
+	err( "Cannot open %s: %s\n", options.modem, modem->errstr() );
+	return( false );
     }
+
     log( "Initializing modem.\n" );
     
     // make modem happy
-    modem->print("\r\r\r\r\r");
-    while (modem->select(100))
+    modem->print( "\r\r\r\r\r" );
+    while( modem->select( 100 ) )
 	modem->drain();
 
     // Send up to nine init strings, in order.
@@ -433,7 +459,7 @@ bool WvDialer::init_modem()
             default:
 	               this_str = &options.init9;	break;
     	}
-    	if( this_str->str[0] ) {
+    	if( !! *this_str ) {
     	    modem->print( "%s\r", *this_str );
     	    log( "Sending: %s\n", *this_str );
 
@@ -451,7 +477,7 @@ bool WvDialer::init_modem()
 
     // If we're using an ISDN modem, allow one second for the SPID
     // settings to kick in.  It dials so fast anyway that no one will care.
-    if( options.isdn.str[0] )
+    if( options.isdn[0] )
 	sleep( 1 );
     
     // Everything worked fine.
@@ -482,10 +508,12 @@ void WvDialer::async_dial()
     }
 	
     if( stat == Dial ) {
-    	// Construct the dial string.  We use the dial command, prefix, and
-    	// phone number as specified in the config file.
-	WvString s( "%s %s%s\r", options.dial_cmd,
+    	// Construct the dial string.  We use the dial command, prefix,
+	// area code, and phone number as specified in the config file.
+	WvString s( "%s %s%s%s%s\r", options.dial_cmd,
 				 options.dial_prefix,
+				 !options.dial_prefix ? "" : ",",
+				 options.areacode,
 				 options.phnum );
 	modem->print( s );
 	log( "Sending: %s\n", s );
@@ -506,7 +534,7 @@ void WvDialer::async_dial()
 	return;
     case 0:	// CONNECT
 	if( options.stupid_mode == true ) {
-	    log( "Carrier detected.  Starting ppp.\n" );
+	    log( "Carrier detected.  Starting PPP immediately.\n" );
 	    start_ppp();
 	} else {
 	    log( "Carrier detected.  Waiting for prompt.\n" );
@@ -560,23 +588,25 @@ void WvDialer::async_dial()
 void WvDialer::start_ppp()
 /************************/
 {
+    if( chat_mode ) exit(0); // pppd is already started...
+
     WvString	addr_colon( "%s:", options.force_addr );
 
-    char *argv[] = {
-	options.where_pppd.str,
+    char const *argv[] = {
+	options.where_pppd,
 	"modem",
 	"crtscts",
 	"defaultroute",
 	"usehostname",
 	"-detach",
-	"user", options.login.str,
-	options.force_addr.str[0] ? addr_colon.str : "noipdefault",
+	"user", options.login,
+	options.force_addr[0] ? (const char *)addr_colon : "noipdefault",
 	options.new_pppd ? "call" : NULL, 
 	options.new_pppd ? "wvdial" : NULL,
 	NULL
     };
 
-    if( access( options.where_pppd.str, X_OK ) != 0 ) {
+    if( access( options.where_pppd, X_OK ) != 0 ) {
         err( "Unable to run %s.\n", options.where_pppd );
         err( "Check permissions, or specify a \"PPPD Path\" option "
              "in wvdial.conf.\n" );
@@ -612,7 +642,7 @@ void WvDialer::async_waitprompt()
 /*******************************/
 {
     int		received;
-    char *	prompt_response;
+    const char *prompt_response;
 
     if( options.carrier_check == true ) {
 	if( !modem || !modem->carrier() ) {
@@ -660,8 +690,9 @@ int WvDialer::wait_for_modem( char * 	strs[],
 {
     off_t	onset;
     char *	soff;
-    int		result;
+    int		result = -1;
     int		len;
+    const char *ppp_marker = NULL;
 
     while( modem->select( timeout ) ) {
 	last_rx = time( NULL );
@@ -686,13 +717,6 @@ int WvDialer::wait_for_modem( char * 	strs[],
 
 	strlwr( buffer + onset );
 
-	// Search the buffer for a valid menu option...
-	// If guess_menu returns an offset, we zap everything before it in
-	// the buffer.  This prevents finding the same menu option twice.
-	char *	ppp_marker = brain->guess_menu( buffer );
-	if( ppp_marker != NULL )
-	    memset( buffer, ' ', ppp_marker-buffer );
-	
 	// Now we can search using strstr.
 	for( result = 0; strs[ result ] != NULL; result++ ) {
 	    len = strlen( strs[ result ] );
@@ -704,21 +728,34 @@ int WvDialer::wait_for_modem( char * 	strs[],
 		memmove( buffer, soff + len,
 			 offset - (int)( soff+len - buffer ) );
 		offset -= (int)( soff+len - buffer );
-		return( result );
+		break;
 	    }
 	}
+	
+	if (strs[ result ] == NULL)
+	    result = -1;
 
-	// Looks like we did not find anything.  Is the buffer full yet?
+	// Search the buffer for a valid menu option...
+	// If guess_menu returns an offset, we zap everything before it in
+	// the buffer.  This prevents finding the same menu option twice.
+	ppp_marker = brain->guess_menu( buffer );
+	if( ppp_marker != NULL )
+	    memset( buffer, ' ', ppp_marker-buffer );
+	
+	// Looks like we didn't find anything.  Is the buffer full yet?
 	if( offset == INBUF_SIZE ) {
 	    // yes, move the second half to the first half for next time.
 	    memmove( buffer, buffer + INBUF_SIZE/2,
 		     INBUF_SIZE - INBUF_SIZE/2 );
 	    offset = INBUF_SIZE/2;
 	}
+	
+	if (result != -1)
+	    break;
     }
     
     buffer[ offset ] = 0;
-    return( -1 ); // timeout
+    return( result ); // -1 == timeout
 }
 
 int WvDialer::async_wait_for_modem( char * strs[], bool neednl, bool verbose )
