@@ -1,6 +1,6 @@
 /*
  * Worldvisions Weaver Software:
- *   Copyright (C) 1997, 1998 Worldvisions Computer Technology, Inc.
+ *   Copyright (C) 1997, 1998, 1999 Worldvisions Computer Technology, Inc.
  *
  * Re-write of wvpapsecrets.h.  This one supports CHAP as well, and is also
  * much safer.
@@ -39,7 +39,8 @@ private:
     bool load_file( char * filename );
     void nuke_contents();
     bool write_file( char * filename );
-    void do_secret( char * username, char * password, char * remote );
+    void do_secret( const char * username, const char * password,
+		    const char * remote );
 };
 
 #endif __WVPAPCHAP_H
